@@ -292,7 +292,9 @@ def calculate_feature_matrix(features, entityset=None, cutoff_time=None, instanc
                     pd.MultiIndex.from_frame(cutoff_time[["instance_id", "time"]],
                                              names=feature_matrix.index.names))
             else:
-                feature_matrix = feature_matrix.reindex(cutoff_time[1], level=0)
+                # Maintain index dtype
+                index_dtype = feature_matrix.index.get_level_values(0).dtype
+                feature_matrix = feature_matrix.reindex(cutoff_time[1].astype(index_dtype), level=0)
             if not cutoff_time_in_index:
                 feature_matrix.reset_index(level='time', drop=True, inplace=True)
 
@@ -557,7 +559,7 @@ def approximate_features(feature_set, cutoff_time, window, entityset,
 def scatter_warning(num_scattered_workers, num_workers):
     if num_scattered_workers != num_workers:
         scatter_warning = "EntitySet was only scattered to {} out of {} workers"
-        warnings.warn(scatter_warning.format(num_scattered_workers, num_workers))
+        logger.warning(scatter_warning.format(num_scattered_workers, num_workers))
 
 
 def parallel_calculate_chunks(cutoff_time, chunk_size, feature_set, approximate, training_window,
