@@ -98,7 +98,7 @@ def test_full_entity_trans_of_agg(pd_es):
                                       feature_set=feature_set)
     df = calculator.run(np.array([1]))
 
-    v = df[trans_feat.get_name()][1]
+    v = df[trans_feat.get_name()].values[0]
     assert v == 82
 
 
@@ -306,8 +306,7 @@ def test_make_agg_feat_of_grandchild_entity(es):
     df = calculator.run(np.array([0]))
     if isinstance(df, dd.DataFrame):
         df = df.compute().set_index('id')
-        df.index = pd.Int64Index(df.index)
-    v = df[agg_feat.get_name()][0]
+    v = df[agg_feat.get_name()].values[0]
     assert (v == 10)
 
 
@@ -390,10 +389,9 @@ def test_make_agg_feat_where_count_and_device_type_feat(es):
     df = calculator.run(np.array([0]))
     if isinstance(df, dd.DataFrame):
         df = df.compute().set_index('id')
-        df.index = pd.Int64Index(df.index)
     name = feat.get_name()
     instances = df[name]
-    assert (instances[0] == 1)
+    assert (instances.values[0] == 1)
 
 
 def test_make_agg_feat_where_count_or_device_type_feat(es):
@@ -419,10 +417,9 @@ def test_make_agg_feat_where_count_or_device_type_feat(es):
     df = calculator.run(np.array([0]))
     if isinstance(df, dd.DataFrame):
         df = df.compute().set_index('id')
-        df.index = pd.Int64Index(df.index)
     name = feat.get_name()
     instances = df[name]
-    assert (instances[0] == 3)
+    assert (instances.values[0] == 3)
 
 
 def test_make_agg_feat_of_agg_feat(es):
@@ -437,8 +434,7 @@ def test_make_agg_feat_of_agg_feat(es):
     df = calculator.run(np.array([0]))
     if isinstance(df, dd.DataFrame):
         df = df.compute().set_index('id')
-        df.index = pd.Int64Index(df.index)
-    v = df[customer_sum_feat.get_name()][0]
+    v = df[customer_sum_feat.get_name()].values[0]
     assert (v == 10)
 
 
@@ -536,8 +532,7 @@ def test_make_dfeat_of_agg_feat_on_self(es):
     df = calculator.run(np.array([0]))
     if isinstance(df, dd.DataFrame):
         df = df.compute().set_index('id')
-        df.index = pd.Int64Index(df.index)
-    v = df[num_customers_feat.get_name()][0]
+    v = df[num_customers_feat.get_name()].values[0]
     assert (v == 3)
 
 
@@ -566,8 +561,7 @@ def test_make_dfeat_of_agg_feat_through_parent(es):
     df = calculator.run(np.array([0]))
     if isinstance(df, dd.DataFrame):
         df = df.compute().set_index('id')
-        df.index = pd.Int64Index(df.index)
-    v = df[num_stores_feat.get_name()][0]
+    v = df[num_stores_feat.get_name()].values[0]
     assert (v == 3)
 
 
@@ -598,8 +592,7 @@ def test_make_deep_agg_feat_of_dfeat_of_agg_feat(es):
     df = calculator.run(np.array([0]))
     if isinstance(df, dd.DataFrame):
         df = df.compute().set_index('id')
-        df.index = pd.Int64Index(df.index)
-    v = df[purchase_popularity.get_name()][0]
+    v = df[purchase_popularity.get_name()].values[0]
     assert (v == 38.0 / 10.0)
 
 
@@ -868,8 +861,7 @@ def test_with_features_built_from_es_metadata(es):
     df = calculator.run(np.array([0]))
     if isinstance(df, dd.DataFrame):
         df = df.compute().set_index('id')
-        df.index = pd.Int64Index(df.index)
-    v = df[agg_feat.get_name()][0]
+    v = df[agg_feat.get_name()].values[0]
     assert (v == 10)
 
 
